NOTE:

Following is a fork of feedjack from 2005. It includes fixes to support new Django releases,
nothing more. If someone is interested maintaining the fork with bugfixed and new features,
let me know (or in case better django product arises).

Domen (domen@dev.si)

---

Feedjack is a feed aggregator writen in Python using the Django web development
framework.

Like the Planet feed aggregator:

    * It downloads feeds and aggregate their contents in a single site
    * The new aggregated site has a feed of its own (atom and rss)
    * It uses Mark Pilgrim’s excelent FeedParser
    * The subscribers list can be exported as OPML and FOAF

But FeedJack also has some advantages:

    * It handles historical data, you can read old posts
    * It parses a lot more info, including post categories
    * It generates pages with posts of a certain category
    * It generates pages with posts from a certain subscriber
    * It generates pages with posts of a certain category from a certain
       subcriber
    * A cloud tag/folksonomy (hype 2.0 compliant) for every page and every
      subscriber
    * It uses Django templates
    * The administration is done via web (using Django's kickass autogenerated
      and magical admin site), and can handle multiple planets
    * Extensive use of django’s internal cache engine. Most of the time you
      will have no database hits when serving pages.

Web site is http://www.feedjack.org/
